@@ -1,15 +1,16 @@
 from ..utils import getEndpointUrl
 from abstract_apis import asyncPostRequest,asyncGetRequest
 
-async def get_rate_limit_url(method_name, *args, **kwargs):
-    url = getEndpointUrl("/rate_limit")
+async def async_get_rate_limit_url(method_name, *args, **kwargs):
+    url = getEndpointUrl("rate_limit")
+    kwargs["method"]=method_name or kwargs.get("method")
     for arg in args:
         if "method" not in kwargs:
             kwargs["method"] = arg
     return await asyncGetRequest(url, kwargs)
     
-async def log_response(method_name, response_data,endpoint=None, *args, **kwargs):
-    url = getEndpointUrl(endpoint or "/log_response")
+async def async_log_response(method_name, response_data,endpoint=None, *args, **kwargs):
+    url = getEndpointUrl("/log_response")
     # Assuming that `args` is supposed to update `kwargs` for unspecified keys
     for arg in args:
         if "method" not in kwargs:
